summaryrefslogtreecommitdiffstats
path: root/src/base
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit3fcef18c75f7cd751ed706c12977230242fb817d (patch)
treea94c2497a3923ed9972e71c5bbba0697882c1427 /src/base
parent80ee419f074dc252449791628d4584b5c0ea0c9b (diff)
downloadrosegarden-3fcef18c75f7cd751ed706c12977230242fb817d.tar.gz
rosegarden-3fcef18c75f7cd751ed706c12977230242fb817d.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/rosegarden@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/base')
-rw-r--r--src/base/AnalysisTypes.cpp20
-rw-r--r--src/base/AnalysisTypes.h2
-rw-r--r--src/base/Instrument.h4
-rw-r--r--src/base/MidiProgram.h2
4 files changed, 14 insertions, 14 deletions
diff --git a/src/base/AnalysisTypes.h b/src/base/AnalysisTypes.h
index fb99cac..d7eabad 100644
--- a/src/base/AnalysisTypes.h
+++ b/src/base/AnalysisTypes.h
@@ -71,7 +71,7 @@ class ChordLabel
{
public:
ChordLabel();
- ChordLabel(Key key, int tqmask, int bass);
+ ChordLabel(Key key, int mask, int bass);
ChordLabel(ChordType type, int rootPitch, int inversion = 0) :
m_data(type, rootPitch, inversion) { };
int rootPitch();
diff --git a/src/base/Instrument.h b/src/base/Instrument.h
index fe1bc98..8c348f0 100644
--- a/src/base/Instrument.h
+++ b/src/base/Instrument.h
@@ -220,7 +220,7 @@ public:
//
virtual std::string toXmlString();
- // Get and set the tqparent device
+ // Get and set the parent device
//
Device* getDevice() const { return m_device; }
void setDevice(Device* dev) { m_device = dev; }
@@ -263,7 +263,7 @@ private:
Device *m_device;
// Do we send at this intrument or do we leave these
- // things up to the tqparent device and God? These are
+ // things up to the parent device and God? These are
// directly relatable to GUI elements
//
bool m_sendBankSelect;
diff --git a/src/base/MidiProgram.h b/src/base/MidiProgram.h
index a5ab7a9..e44f631 100644
--- a/src/base/MidiProgram.h
+++ b/src/base/MidiProgram.h
@@ -168,7 +168,7 @@ private:
};
-// MidiFilter is a bittqmask of MappedEvent::MappedEventType.
+// MidiFilter is a bitmask of MappedEvent::MappedEventType.
// Look in sound/MappedEvent.h
//
typedef unsigned int MidiFilter;
diff --git a/src/base/AnalysisTypes.cpp b/src/base/AnalysisTypes.cpp
index 316c58f..b2d8727 100644
--- a/src/base/AnalysisTypes.cpp
+++ b/src/base/AnalysisTypes.cpp
@@ -109,7 +109,7 @@ AnalysisHelper::labelChords(CompositionTimeSliceAdapter &c, Segment &s,
if ((*i)->isa(Note::EventType)) {
int bass = 999;
- int tqmask = 0;
+ int mask = 0;
GlobalChord chord(c, i, quantizer);
if (chord.size() == 0) continue;
@@ -121,15 +121,15 @@ AnalysisHelper::labelChords(CompositionTimeSliceAdapter &c, Segment &s,
assert(bass == 999); // should be in ascending order already
bass = pitch;
}
- tqmask |= 1 << (pitch % 12);
+ mask |= 1 << (pitch % 12);
}
}
i = chord.getFinalElement();
- if (tqmask == 0) continue;
+ if (mask == 0) continue;
- ChordLabel ch(key, tqmask, bass);
+ ChordLabel ch(key, mask, bass);
if (ch.isValid())
{
@@ -154,15 +154,15 @@ ChordLabel::ChordLabel()
checkMap();
}
-ChordLabel::ChordLabel(Key key, int tqmask, int /* bass */) :
+ChordLabel::ChordLabel(Key key, int mask, int /* bass */) :
m_data()
{
checkMap();
// Look for a chord built on an unaltered scale step of the current key.
- for (ChordMap::iterator i = m_chordMap.find(tqmask);
- i != m_chordMap.end() && i->first==tqmask; ++i)
+ for (ChordMap::iterator i = m_chordMap.find(mask);
+ i != m_chordMap.end() && i->first==mask; ++i)
{
if (Pitch(i->second.m_rootPitch).isDiatonicInKey(key))
@@ -233,7 +233,7 @@ ChordLabel::checkMap()
// What the basicChordMasks mean: each bit set in each one represents
// a pitch class (pitch%12) in a chord. C major has three pitch
// classes, C, E, and G natural; if you take the MIDI pitches
// of those notes modulo 12, you get 0, 4, and 7, so the tqmask for
// major triads is (1<<0)+(1<<4)+(1<<7). All the masks are for chords
// built on C.
@@ -249,8 +249,8 @@ ChordLabel::checkMap()
1 + (1<<3) + (1<<6) + (1<<9) // diminished 7th
};
// Each tqmask is inserted into the map rotated twelve ways; each
// rotation is a tqmask you would get by transposing the chord
// to have a new root (i.e., C, C#, D, D#, E, F...)
for (int i = 0; i < 8; ++i)
@@ -233,7 +233,7 @@ ChordLabel::checkMap()
// a pitch class (pitch%12) in a chord. C major has three pitch
// classes, C, E, and G natural; if you take the MIDI pitches
- // of those notes modulo 12, you get 0, 4, and 7, so the tqmask for
+ // of those notes modulo 12, you get 0, 4, and 7, so the mask for
// major triads is (1<<0)+(1<<4)+(1<<7). All the masks are for chords
// built on C.
@@ -249,8 +249,8 @@ ChordLabel::checkMap()
1 + (1<<3) + (1<<6) + (1<<9) // diminished 7th
};
- // Each tqmask is inserted into the map rotated twelve ways; each
- // rotation is a tqmask you would get by transposing the chord
+ // Each mask is inserted into the map rotated twelve ways; each
+ // rotation is a mask you would get by transposing the chord
// to have a new root (i.e., C, C#, D, D#, E, F...)
for (int i = 0; i < 8; ++i)